import { type GossipsubMessage } from "@chainsafe/libp2p-gossipsub";
import { type TopicScoreParams } from "@chainsafe/libp2p-gossipsub/score";
import type { Address, EventCallback, PeerId, StreamHandler } from "@libp2p/interface";
import { type MultiaddrInput } from "@multiformats/multiaddr";
import { type LoggerOptions } from "@sfroment/logger";
import { Message } from "./proto/drp/network/v1/messages_pb.js";
export * from "./stream.js";
export declare const DRP_MESSAGE_PROTOCOL = "/drp/message/0.0.1";
export declare const BOOTSTRAP_NODES: string[];
export interface DRPNetworkNodeConfig {
    announce_addresses?: string[];
    bootstrap?: boolean;
    bootstrap_peers?: string[];
    browser_metrics?: boolean;
    listen_addresses?: string[];
    log_config?: LoggerOptions;
    private_key_seed?: string;
    peer_discovery?: boolean;
    pubsub_peer_discovery_interval?: number;
}
export declare class DRPNetworkNode {
    private _config?;
    private _node?;
    private _pubsub?;
    peerId: string;
    constructor(config?: DRPNetworkNodeConfig);
    start(): Promise<void>;
    stop(): Promise<void>;
    restart(config?: DRPNetworkNodeConfig): Promise<void>;
    getPeerMultiaddrs(peerId: PeerId | string): Promise<Address[]>;
    isDialable(timeout?: number): Promise<boolean>;
    waitForPeer(peerId: string | PeerId, timeout?: number): Promise<boolean>;
    isSubscribed(topic: string, peerId: PeerId | string, timeout?: number): Promise<boolean>;
    private _sortAddresses;
    changeTopicScoreParams(topic: string, params: TopicScoreParams): void;
    removeTopicScoreParams(topic: string): void;
    subscribe(topic: string): void;
    unsubscribe(topic: string): void;
    connect(addr: MultiaddrInput | MultiaddrInput[]): Promise<void>;
    disconnect(peerId: string): Promise<void>;
    getBootstrapNodes(): string[];
    getMultiaddrs(): string[] | undefined;
    getAllPeers(): string[];
    getGroupPeers(group: string): string[];
    broadcastMessage(topic: string, message: Message): Promise<void>;
    sendMessage(peerId: string, message: Message): Promise<void>;
    sendGroupMessageRandomPeer(group: string, message: Message): Promise<void>;
    addGroupMessageHandler(group: string, handler: EventCallback<CustomEvent<GossipsubMessage>>): void;
    addMessageHandler(handler: StreamHandler): Promise<void>;
    addCustomMessageHandler(protocol: string | string[], handler: StreamHandler): Promise<void>;
}
//# sourceMappingURL=node.d.ts.map