import { BinaryReader, BinaryWriter } from "@bufbuild/protobuf/wire";
import { AggregatedAttestation, Attestation, DRPState, Vertex } from "../../object/v1/object_pb.js";
export declare const protobufPackage = "drp.network.v1";
export declare enum MessageType {
    MESSAGE_TYPE_UNSPECIFIED = 0,
    MESSAGE_TYPE_FETCH_STATE = 1,
    MESSAGE_TYPE_FETCH_STATE_RESPONSE = 2,
    MESSAGE_TYPE_UPDATE = 3,
    MESSAGE_TYPE_SYNC = 4,
    MESSAGE_TYPE_SYNC_ACCEPT = 5,
    MESSAGE_TYPE_SYNC_REJECT = 6,
    MESSAGE_TYPE_ATTESTATION_UPDATE = 7,
    MESSAGE_TYPE_CUSTOM = 8,
    MESSAGE_TYPE_TOPIC_DISCOVERY_REQUEST = 9,
    MESSAGE_TYPE_TOPIC_DISCOVERY_RESPONSE = 10,
    UNRECOGNIZED = -1
}
export declare function messageTypeFromJSON(object: any): MessageType;
export declare function messageTypeToJSON(object: MessageType): string;
export interface Message {
    sender: string;
    type: MessageType;
    data: Uint8Array;
}
export interface FetchState {
    objectId: string;
    vertexHash: string;
}
export interface FetchStateResponse {
    objectId: string;
    vertexHash: string;
    aclState: DRPState | undefined;
    drpState: DRPState | undefined;
}
export interface Update {
    objectId: string;
    vertices: Vertex[];
    attestations: Attestation[];
}
export interface AttestationUpdate {
    objectId: string;
    attestations: Attestation[];
}
export interface Sync {
    objectId: string;
    vertexHashes: string[];
}
export interface SyncAccept {
    objectId: string;
    requested: Vertex[];
    attestations: AggregatedAttestation[];
    requesting: string[];
}
export interface SyncReject {
}
export interface TopicDiscoveryRequest {
    topic: string;
}
export interface TopicDiscoveryResponse {
    subscribers: {
        [key: string]: TopicDiscoveryResponse_Subscribers;
    };
}
export interface TopicDiscoveryResponse_Subscribers {
    multiaddrs: string[];
}
export interface TopicDiscoveryResponse_SubscribersEntry {
    key: string;
    value: TopicDiscoveryResponse_Subscribers | undefined;
}
export declare const Message: MessageFns<Message>;
export declare const FetchState: MessageFns<FetchState>;
export declare const FetchStateResponse: MessageFns<FetchStateResponse>;
export declare const Update: MessageFns<Update>;
export declare const AttestationUpdate: MessageFns<AttestationUpdate>;
export declare const Sync: MessageFns<Sync>;
export declare const SyncAccept: MessageFns<SyncAccept>;
export declare const SyncReject: MessageFns<SyncReject>;
export declare const TopicDiscoveryRequest: MessageFns<TopicDiscoveryRequest>;
export declare const TopicDiscoveryResponse: MessageFns<TopicDiscoveryResponse>;
export declare const TopicDiscoveryResponse_Subscribers: MessageFns<TopicDiscoveryResponse_Subscribers>;
export declare const TopicDiscoveryResponse_SubscribersEntry: MessageFns<TopicDiscoveryResponse_SubscribersEntry>;
type Builtin = Date | Function | Uint8Array | string | number | boolean | undefined;
export type DeepPartial<T> = T extends Builtin ? T : T extends globalThis.Array<infer U> ? globalThis.Array<DeepPartial<U>> : T extends ReadonlyArray<infer U> ? ReadonlyArray<DeepPartial<U>> : T extends {} ? {
    [K in keyof T]?: DeepPartial<T[K]>;
} : Partial<T>;
type KeysOfUnion<T> = T extends T ? keyof T : never;
export type Exact<P, I extends P> = P extends Builtin ? P : P & {
    [K in keyof P]: Exact<P[K], I[K]>;
} & {
    [K in Exclude<keyof I, KeysOfUnion<P>>]: never;
};
export interface MessageFns<T> {
    encode(message: T, writer?: BinaryWriter): BinaryWriter;
    decode(input: BinaryReader | Uint8Array, length?: number): T;
    fromJSON(object: any): T;
    toJSON(message: T): unknown;
    create<I extends Exact<DeepPartial<T>, I>>(base?: I): T;
    fromPartial<I extends Exact<DeepPartial<T>, I>>(object: I): T;
}
export {};
//# sourceMappingURL=messages_pb.d.ts.map